@@ -23,6 +23,7 @@ class Connection(object):
         try:
             if self.__debug:
                 print(str(self.__config))
+            self.__autocommit = True
             self.__conn = pymysql.connect(**self.__config, cursorclass=cursors.DictCursor)
             if self.__debug:
                 print('mysql connect success')
@@ -57,81 +58,96 @@ class Connection(object):
         try:
             if self.__debug:
                 print(f"sql: {sql}")
+            if self.__conn is None:
+                self.open(self.__debug)
             self.__conn.autocommit(self.__autocommit)
             cursor = self.__conn.cursor()
             cursor.execute(sql)
             result = cursor.fetchone()
             cursor.close()
             return result
-        except Exception as e:
-            raise e
+        except pymysql.OperationalError:
+            self.open(self.__debug)
 
     def fetchall(self, sql):
         try:
             if self.__debug:
                 print(f"sql: {sql}")
+            if self.__conn is None:
+                self.open(self.__debug)
             self.__conn.autocommit(self.__autocommit)
             cursor = self.__conn.cursor()
             cursor.execute(sql)
             result = cursor.fetchall()
             cursor.close()
             return result
-        except Exception as e:
-            raise e
+        except pymysql.OperationalError:
+            self.open(self.__debug)
 
     def batch(self, sql):
         try:
             if self.__debug:
                 print(f"batch sql: {sql}")
+            if self.__conn is None:
+                self.open(self.__debug)
             self.__conn.autocommit(self.__autocommit)
             cursor = self.__conn.cursor()
             cursor.execute(sql)
             return Batch(cursor)
-        except Exception as e:
-            raise e
+        except pymysql.OperationalError:
+            self.open(self.__debug)
 
     def insert(self, sql):
         try:
             if self.__debug:
                 print(f"sql: {sql}")
+            if self.__conn is None:
+                self.open(self.__debug)
             self.__conn.autocommit(self.__autocommit)
             cursor = self.__conn.cursor()
             cursor.execute(sql)
             last_insert_id = cursor.lastrowid
             cursor.close()
             return last_insert_id
-        except Exception as e:
-            raise e
+        except pymysql.OperationalError:
+            self.open(self.__debug)
 
     def insert_batch(self, sql, data):
         try:
             if self.__debug:
                 print(f"sql: {sql}")
+            if self.__conn is None:
+                self.open(self.__debug)
             self.__conn.autocommit(self.__autocommit)
             cursor = self.__conn.cursor()
             cursor.executemany(sql, data)
             last_insert_id = cursor.lastrowid
             cursor.close()
             return last_insert_id
-        except Exception as e:
-            raise e
+        except pymysql.OperationalError:
+            self.open(self.__debug)
 
     def execute(self, sql):
         try:
             if self.__debug:
                 print(f"sql: {sql}")
+            if self.__conn is None:
+                self.open(self.__debug)
             self.__conn.autocommit(self.__autocommit)
             cursor = self.__conn.cursor()
             num = cursor.execute(sql)
             cursor.close()
             return num
-        except Exception as e:
-            raise e
+        except pymysql.OperationalError:
+            self.open(self.__debug)
 
     def count(self, sql):
         try:
             if self.__debug:
                 print(f"sql: {sql}")
+            if self.__conn is None:
+                self.open(self.__debug)
+            self.__conn.autocommit(self.__autocommit)
             cursor = self.__conn.cursor()
             cursor.execute(sql)
             data = cursor.fetchone()
@@ -140,13 +156,34 @@ class Connection(object):
                 total = v
             cursor.close()
             return total
-        except Exception as e:
-            raise e
+        except pymysql.OperationalError:
+            self.open(self.__debug)
+
+    def sum(self, sql):
+        try:
+            if self.__debug:
+                print(f"sql: {sql}")
+            if self.__conn is None:
+                self.open(self.__debug)
+            self.__conn.autocommit(self.__autocommit)
+            cursor = self.__conn.cursor()
+            cursor.execute(sql)
+            data = cursor.fetchone()
+            total = 0
+            for v in data.values():
+                total = v
+            cursor.close()
+            return total
+        except pymysql.OperationalError:
+            self.open(self.__debug)
 
     def min(self, sql):
         try:
             if self.__debug:
                 print(f"sql: {sql}")
+            if self.__conn is None:
+                self.open(self.__debug)
+            self.__conn.autocommit(self.__autocommit)
             cursor = self.__conn.cursor()
             cursor.execute(sql)
             data = cursor.fetchone()
@@ -155,13 +192,16 @@ class Connection(object):
                 total = v
             cursor.close()
             return total
-        except Exception as e:
-            raise e
+        except pymysql.OperationalError:
+            self.open(self.__debug)
 
     def max(self, sql):
         try:
             if self.__debug:
                 print(f"sql: {sql}")
+            if self.__conn is None:
+                self.open(self.__debug)
+            self.__conn.autocommit(self.__autocommit)
             cursor = self.__conn.cursor()
             cursor.execute(sql)
             data = cursor.fetchone()
@@ -170,13 +210,16 @@ class Connection(object):
                 total = v
             cursor.close()
             return total
-        except Exception as e:
-            raise e
+        except pymysql.OperationalError:
+            self.open(self.__debug)
 
     def average(self, sql):
         try:
             if self.__debug:
                 print(f"sql: {sql}")
+            if self.__conn is None:
+                self.open(self.__debug)
+            self.__conn.autocommit(self.__autocommit)
             cursor = self.__conn.cursor()
             cursor.execute(sql)
             data = cursor.fetchone()
@@ -185,13 +228,16 @@ class Connection(object):
                 total = v
             cursor.close()
             return total
-        except Exception as e:
-            raise e
+        except pymysql.OperationalError:
+            self.open(self.__debug)
 
     def exists(self, sql):
         try:
             if self.__debug:
                 print(f"sql: {sql}")
+            if self.__conn is None:
+                self.open(self.__debug)
+            self.__conn.autocommit(self.__autocommit)
             cursor = self.__conn.cursor()
             cursor.execute(sql)
             data = cursor.fetchone()
@@ -200,44 +246,52 @@ class Connection(object):
                 total = v
             cursor.close()
             return total == 1
-        except Exception as e:
-            raise e
+        except pymysql.OperationalError:
+            self.open(self.__debug)
 
     def column(self, sql):
         try:
             if self.__debug:
                 print(f"sql: {sql}")
+            if self.__conn is None:
+                self.open(self.__debug)
+            self.__conn.autocommit(self.__autocommit)
             cursor = self.__conn.cursor()
             cursor.execute(sql)
             result = cursor.fetchall()
             cursor.close()
             return result
-        except Exception as e:
-            raise e
+        except pymysql.OperationalError:
+            self.open(self.__debug)
 
     def scalar(self, sql):
         try:
             if self.__debug:
                 print(f"sql: {sql}")
+            if self.__conn is None:
+                self.open(self.__debug)
+            self.__conn.autocommit(self.__autocommit)
             cursor = self.__conn.cursor()
             cursor.execute(sql)
             result = cursor.fetchone()
             cursor.close()
             return result
-        except Exception as e:
-            raise e
+        except pymysql.OperationalError:
+            self.open(self.__debug)
 
     def begin(self):
         try:
             sql = "begin"
             if self.__debug:
                 print(f"sql: {sql}")
+            if self.__conn is None:
+                self.open(self.__debug)
             cursor = self.__conn.cursor()
             cursor.execute(sql)
             cursor.close()
             self.__autocommit = False
-        except Exception as e:
-            raise e
+        except pymysql.OperationalError:
+            self.open(self.__debug)
 
     def rollback(self):
         try:
@@ -248,8 +302,8 @@ class Connection(object):
             cursor.execute(sql)
             cursor.close()
             self.__autocommit = True
-        except Exception as e:
-            raise e
+        except pymysql.OperationalError:
+            self.open(self.__debug)
 
     def commit(self):
         try:
@@ -260,8 +314,8 @@ class Connection(object):
             cursor.execute(sql)
             cursor.close()
             self.__autocommit = True
-        except Exception as e:
-            raise e
+        except pymysql.OperationalError:
+            self.open(self.__debug)
 
     def savepoint(self, identifier):
         try:
@@ -271,8 +325,8 @@ class Connection(object):
             cursor = self.__conn.cursor()
             cursor.execute(sql)
             cursor.close()
-        except Exception as e:
-            raise e
+        except pymysql.OperationalError:
+            self.open(self.__debug)
 
     def rollback_savepoint(self, identifier):
         try:
@@ -282,8 +336,8 @@ class Connection(object):
             cursor = self.__conn.cursor()
             cursor.execute(sql)
             cursor.close()
-        except Exception as e:
-            raise e
+        except pymysql.OperationalError:
+            self.open(self.__debug)
 
     def release_savepoint(self, identifier):
         try:
@@ -293,5 +347,5 @@ class Connection(object):
             cursor = self.__conn.cursor()
             cursor.execute(sql)
             cursor.close()
-        except Exception as e:
-            raise e
+        except pymysql.OperationalError:
+            self.open(self.__debug)
