@@ -1,3 +1,6 @@
+import datetime
+import decimal
+
 from pymyorm.local import local
 import pprint
 
@@ -5,8 +8,6 @@ import pprint
 class Model(object):
     tablename = None
     primary_key = 'id'
-    datetime_fields = []
-    decimal_fields = []
 
     def __init__(self, **kwargs) -> None:
         self.__conn = local.conn
@@ -33,7 +34,8 @@ class Model(object):
         if name.find('_Model__') >= 0:
             self.__dict__[name] = value
         else:
-            self.__dict__['_Model__new_fields'][name] = value
+            if value is not None:
+                self.__dict__['_Model__new_fields'][name] = value
 
     def __getattr__(self, name):
         if name in self.__new_fields:
@@ -110,9 +112,10 @@ class Model(object):
                 self.__new_fields[self.__class__.primary_key] = last_insert_id
         else:
             update_str = ','.join([f"`{k}`='{v}'" for (k, v) in self.__new_fields.items()])
-            sql = f"update `{self.__class__.tablename}` set {update_str} where `{self.__class__.primary_key}`='{self.__old_fields.get(self.__class__.primary_key)}'"
-            self.__sql = sql
-            self.__conn.execute(sql)
+            if update_str != '':
+                sql = f"update `{self.__class__.tablename}` set {update_str} where `{self.__class__.primary_key}`='{self.__old_fields.get(self.__class__.primary_key)}'"
+                self.__sql = sql
+                self.__conn.execute(sql)
 
     def sql(self):
         sql = self.__build_select_sql()
@@ -169,6 +172,11 @@ class Model(object):
                 if len(cond['value']) != 2:
                     raise Exception('condition should have two element')
                 cond_list.append(f"{cond['field']} between '{cond['value'][0]}' and '{cond['value'][1]}'")
+            elif cond['op'] == '':
+                if len(self.__where) > 1:
+                    cond_list.append(f"({cond['value']})")
+                else:
+                    cond_list.append(f"{cond['value']}")
             else:
                 raise Exception(f"syntax error: operator not supported {cond['op']}")
         where_sql = ' and '.join(cond_list)
@@ -218,12 +226,13 @@ class Model(object):
         one = self.__conn.fetchone(sql)
         if one is None:
             return None
-        if self.datetime_fields or self.decimal_fields:
-            for k, v in one.items():
-                if k in self.datetime_fields:
-                    one[k] = v.strftime('%Y-%m-%d %H:%M:%S')
-                elif k in self.decimal_fields:
-                    one[k] = float(v)
+        for k, v in one.items():
+            if isinstance(v, datetime.datetime):
+                one[k] = v.strftime('%Y-%m-%d %H:%M:%S')
+            elif isinstance(v, datetime.date):
+                one[k] = v.strftime('%Y-%m-%d')
+            elif isinstance(v, decimal.Decimal):
+                one[k] = float(v)
         if raw:
             return one
 
@@ -239,13 +248,14 @@ class Model(object):
         all = self.__conn.fetchall(sql)
         if all is None:
             return []
-        if self.datetime_fields or self.decimal_fields:
-            for one in all:
-                for k, v in one.items():
-                    if k in self.datetime_fields:
-                        one[k] = v.strftime('%Y-%m-%d %H:%M:%S')
-                    elif k in self.decimal_fields:
-                        one[k] = float(v)
+        for one in all:
+            for k, v in one.items():
+                if isinstance(v, datetime.datetime):
+                    one[k] = v.strftime('%Y-%m-%d %H:%M:%S')
+                elif isinstance(v, datetime.date):
+                    one[k] = v.strftime('%Y-%m-%d')
+                elif isinstance(v, decimal.Decimal):
+                    one[k] = float(v)
         if raw:
             return all
 
@@ -328,19 +338,26 @@ class Model(object):
 
     def where(self, *args, **kwargs):
         if len(args) > 0:
-            if len(args) != 3:
+            if len(args) == 1:
+                cond = dict()
+                cond['op'] = ''
+                cond['field'] = ''
+                cond['value'] = args[0]
+                self.__where.append(cond)
+            elif len(args) == 3:
+                field = args[0]
+                value = args[2]
+                if field.find('.'):
+                    field = '.'.join([f"`{v}`" for v in field.split('.')])
+                op = args[1].lower()
+                op = ' '.join([o for o in op.split()])
+                cond = dict()
+                cond['op'] = op
+                cond['field'] = field
+                cond['value'] = value
+                self.__where.append(cond)
+            else:
                 raise Exception('where statement error')
-            field = args[0]
-            value = args[2]
-            if field.find('.'):
-                field = '.'.join([f"`{v}`" for v in field.split('.')])
-            op = args[1].lower()
-            op = ' '.join([o for o in op.split()])
-            cond = dict()
-            cond['op'] = op
-            cond['field'] = field
-            cond['value'] = value
-            self.__where.append(cond)
         if len(kwargs) > 0:
             for k, v in kwargs.items():
                 cond = dict()
