@@ -5,7 +5,7 @@ from tests.models.user import User
 
 if __name__ == '__main__':
 
-    Database().connect(**db)
+    Database.connect(**db)
 
     money = User.find().where(id=1).scalar('money')
     print(money)
